﻿using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media.Animation;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "ResourceDictionary 엘리먼트 : Source 속성을 사용해 컨트롤 컴팩트 크기 사용하기";

            #endregion

            Loaded += Page_Loaded;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 페이지 로드시 처리하기 - Page_Loaded(sender, e)

        /// <summary>
        /// 페이지 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Page_Loaded(object sender, RoutedEventArgs e)
        {
            this.frame.Navigate(typeof(SampleStandardSizingPage), null, new SuppressNavigationTransitionInfo());
        }

        #endregion
        #region 표준 크기 라디오 버튼 체크시 처리하기 - standardSizeRadioButton_Checked(sender, e)

        /// <summary>
        /// 표준 크기 라디오 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void standardSizeRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            SampleCompactSizingPage previousPage = this.frame.Content as SampleCompactSizingPage;

            this.frame.Navigate(typeof(SampleStandardSizingPage), null, new SuppressNavigationTransitionInfo());

            if(previousPage != null)
            {
                SampleStandardSizingPage currentPage = this.frame.Content as SampleStandardSizingPage;

                currentPage.CopyState(previousPage);
            }
        }

        #endregion
        #region 컴팩트 크기 라디오 버튼 체크시 처리하기 - compactSizeRadioButton_Checked(sender, e)

        /// <summary>
        /// 컴팩트 크기 라디오 버튼 체크시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void compactSizeRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            SampleStandardSizingPage previousPage = this.frame.Content as SampleStandardSizingPage;

            this.frame.Navigate(typeof(SampleCompactSizingPage), null, new SuppressNavigationTransitionInfo());

            if(previousPage != null)
            {
                SampleCompactSizingPage currentPage = this.frame.Content as SampleCompactSizingPage;

                currentPage.CopyState(previousPage);
            }
        }

        #endregion
    }
}